@@ -31,45 +31,101 @@ from .snappi_convergence import CaptureIter
 from .snappi_convergence import Device
 from .snappi_convergence import DeviceEthernet
 from .snappi_convergence import DeviceIpv4
-from .snappi_convergence import DeviceBgpv4
-from .snappi_convergence import DeviceBgpAdvanced
-from .snappi_convergence import DeviceBgpCapability
-from .snappi_convergence import DeviceBgpSrTePolicy
-from .snappi_convergence import DeviceBgpSrTePolicyNextHop
-from .snappi_convergence import DeviceBgpAddPath
-from .snappi_convergence import DeviceBgpAsPath
-from .snappi_convergence import DeviceBgpAsPathSegment
-from .snappi_convergence import DeviceBgpAsPathSegmentIter
-from .snappi_convergence import DeviceBgpTunnelTlv
-from .snappi_convergence import DeviceBgpSegmentList
-from .snappi_convergence import DeviceBgpSegment
-from .snappi_convergence import DeviceBgpSegmentIter
-from .snappi_convergence import DeviceBgpSegmentListIter
-from .snappi_convergence import DeviceBgpRemoteEndpointSubTlv
-from .snappi_convergence import DeviceBgpPreferenceSubTlv
-from .snappi_convergence import DeviceBgpBindingSubTlv
-from .snappi_convergence import DeviceBgpExplicitNullLabelPolicySubTlv
-from .snappi_convergence import DeviceBgpTunnelTlvIter
-from .snappi_convergence import DeviceBgpCommunity
-from .snappi_convergence import DeviceBgpCommunityIter
-from .snappi_convergence import DeviceBgpSrTePolicyIter
-from .snappi_convergence import DeviceBgpv4Route
-from .snappi_convergence import DeviceBgpv4RouteAddress
-from .snappi_convergence import DeviceBgpv4RouteAddressIter
-from .snappi_convergence import DeviceBgpRouteAdvanced
-from .snappi_convergence import DeviceBgpv4RouteIter
-from .snappi_convergence import DeviceBgpv6Route
-from .snappi_convergence import DeviceBgpv6RouteAddress
-from .snappi_convergence import DeviceBgpv6RouteAddressIter
-from .snappi_convergence import DeviceBgpv6RouteIter
+from .snappi_convergence import DeviceIpv4Iter
 from .snappi_convergence import DeviceIpv6
-from .snappi_convergence import DeviceBgpv6
-from .snappi_convergence import DeviceBgpv6SegmentRouting
+from .snappi_convergence import DeviceIpv6Iter
+from .snappi_convergence import DeviceEthernetIter
+from .snappi_convergence import DeviceIpv4Loopback
+from .snappi_convergence import DeviceIpv4LoopbackIter
+from .snappi_convergence import DeviceIpv6Loopback
+from .snappi_convergence import DeviceIpv6LoopbackIter
+from .snappi_convergence import DeviceIsisRouter
+from .snappi_convergence import DeviceIsisMultiInstance
+from .snappi_convergence import IsisInterface
+from .snappi_convergence import IsisInterfaceLevel
+from .snappi_convergence import IsisMT
+from .snappi_convergence import IsisMTIter
+from .snappi_convergence import LinkStateTE
+from .snappi_convergence import LinkStatepriorityBandwidths
+from .snappi_convergence import LinkStateTEIter
+from .snappi_convergence import IsisInterfaceAuthentication
+from .snappi_convergence import IsisInterfaceAdvanced
+from .snappi_convergence import IsisInterfaceLinkProtection
+from .snappi_convergence import IsisInterfaceIter
+from .snappi_convergence import IsisBasic
+from .snappi_convergence import IsisAdvanced
+from .snappi_convergence import IsisAuthentication
+from .snappi_convergence import IsisAuthenticationBase
+from .snappi_convergence import IsisV4RouteRange
+from .snappi_convergence import V4RouteAddress
+from .snappi_convergence import V4RouteAddressIter
+from .snappi_convergence import IsisV4RouteRangeIter
+from .snappi_convergence import IsisV6RouteRange
+from .snappi_convergence import V6RouteAddress
+from .snappi_convergence import V6RouteAddressIter
+from .snappi_convergence import IsisV6RouteRangeIter
+from .snappi_convergence import DeviceBgpRouter
+from .snappi_convergence import BgpV4Interface
+from .snappi_convergence import BgpV4Peer
+from .snappi_convergence import BgpAdvanced
+from .snappi_convergence import BgpCapability
+from .snappi_convergence import BgpV4RouteRange
+from .snappi_convergence import BgpRouteAdvanced
+from .snappi_convergence import BgpCommunity
+from .snappi_convergence import BgpCommunityIter
+from .snappi_convergence import BgpAsPath
+from .snappi_convergence import BgpAsPathSegment
+from .snappi_convergence import BgpAsPathSegmentIter
+from .snappi_convergence import BgpAddPath
+from .snappi_convergence import BgpV4RouteRangeIter
+from .snappi_convergence import BgpV6RouteRange
+from .snappi_convergence import BgpV6RouteRangeIter
+from .snappi_convergence import BgpSrteV4Policy
+from .snappi_convergence import BgpExtCommunity
+from .snappi_convergence import BgpExtCommunityIter
+from .snappi_convergence import BgpSrteV4TunnelTlv
+from .snappi_convergence import BgpSrteRemoteEndpointSubTlv
+from .snappi_convergence import BgpSrteColorSubTlv
+from .snappi_convergence import BgpSrteBindingSubTlv
+from .snappi_convergence import BgpSrtePreferenceSubTlv
+from .snappi_convergence import BgpSrtePolicyPrioritySubTlv
+from .snappi_convergence import BgpSrtePolicyNameSubTlv
+from .snappi_convergence import BgpSrteExplicitNullLabelPolicySubTlv
+from .snappi_convergence import BgpSrteSegmentList
+from .snappi_convergence import BgpSrteSegment
+from .snappi_convergence import BgpSrteSegmentATypeSubTlv
+from .snappi_convergence import BgpSrteSegmentBTypeSubTlv
+from .snappi_convergence import BgpSrteSRv6SIDEndpointBehaviorAndStructure
+from .snappi_convergence import BgpSrteSegmentCTypeSubTlv
+from .snappi_convergence import BgpSrteSrMplsSid
+from .snappi_convergence import BgpSrteSegmentDTypeSubTlv
+from .snappi_convergence import BgpSrteSegmentETypeSubTlv
+from .snappi_convergence import BgpSrteSegmentFTypeSubTlv
+from .snappi_convergence import BgpSrteSegmentGTypeSubTlv
+from .snappi_convergence import BgpSrteSegmentHTypeSubTlv
+from .snappi_convergence import BgpSrteSegmentITypeSubTlv
+from .snappi_convergence import BgpSrteSegmentJTypeSubTlv
+from .snappi_convergence import BgpSrteSegmentKTypeSubTlv
+from .snappi_convergence import BgpSrteSegmentIter
+from .snappi_convergence import BgpSrteSegmentListIter
+from .snappi_convergence import BgpSrteV4TunnelTlvIter
+from .snappi_convergence import BgpSrteV4PolicyIter
+from .snappi_convergence import BgpSrteV6Policy
+from .snappi_convergence import BgpSrteV6TunnelTlv
+from .snappi_convergence import BgpSrteV6TunnelTlvIter
+from .snappi_convergence import BgpSrteV6PolicyIter
+from .snappi_convergence import BgpV4PeerIter
+from .snappi_convergence import BgpV4InterfaceIter
+from .snappi_convergence import BgpV6Interface
+from .snappi_convergence import BgpV6Peer
+from .snappi_convergence import BgpV6SegmentRouting
+from .snappi_convergence import BgpV6PeerIter
+from .snappi_convergence import BgpV6InterfaceIter
 from .snappi_convergence import DeviceIter
 from .snappi_convergence import Flow
 from .snappi_convergence import FlowTxRx
 from .snappi_convergence import FlowPort
-from .snappi_convergence import FlowDevice
+from .snappi_convergence import FlowRouter
 from .snappi_convergence import FlowHeader
 from .snappi_convergence import FlowCustom
 from .snappi_convergence import FlowEthernet
@@ -388,6 +444,7 @@ from .snappi_convergence import ConvergenceState
 from .snappi_convergence import TransmitState
 from .snappi_convergence import LinkState
 from .snappi_convergence import RouteState
+from .snappi_convergence import ProtocolState
 from .snappi_convergence import PingRequest
 from .snappi_convergence import Ping
 from .snappi_convergence import PingIpv4
